Layer class

Inheritance

Constructors

Layer(int nIn, int nOut, {bool useGelu = true})

Properties

bias Tensor
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useGelu bool
final
weights Tensor
final

Methods

forward(Tensor x) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parameters() List<Tensor>
override
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited