Module class abstract
- Implementers
- AFTAttention
- AFTAttention
- AFTAttention
- AFTAttention
- AFTCrossAttention
- AFTCrossAttention
- CrossAttentionHead
- Layer
- LayerNorm
- Linear
- MLP
- MultiHeadAFT
- MultiHeadAFT
- MultiHeadAFTCross
- MultiHeadAFTCross
- MultiHeadAttention
- MultiHeadCrossAttention
- SelfAttention
- Transformer
- TransformerBlock
- TransformerDecoder
- TransformerDecoder
- TransformerDecoder
- TransformerDecoderBlock
- TransformerDecoderBlock
- TransformerDecoderBlock
- TransformerEncoder
- TransformerEncoder
- TransformerEncoderBlock
- TransformerEncoderBlock
Constructors
- Module()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parameters(
) → List< Tensor> -
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited