MuZeroSearch class

Constructors

MuZeroSearch(MuZeroModel model)

Properties

discount double
final
hashCode int
The hash code for this object.
no setterinherited
model MuZeroModel
final
pb_c_base double
final
pb_c_init double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

filterPriors(List<double> logits, List<int> legalActions) Map<int, double>
Public version of prior filtering used by the Trainer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runSimulation(MCTSNode root) → void
Performs a single MCTS simulation (Select -> Expand -> Evaluate -> Backup)
Main entry point for playing: Runs simulations and returns the best move.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited