MuZeroModel class

Constructors

MuZeroModel(TransformerDecoder transformer, int embedSize)

Properties

embedSize int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformer TransformerDecoder
final

Methods

dynamics(Tensor state, int action) Map<String, Tensor>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(Tensor state) Map<String, Tensor>
represent(List<int> observations) Tensor
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited