MoveCodec class

Constructors

MoveCodec()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

indexToUci(int index) String
Decodes a MuZero move index (0-4095) into a UCI string (e.g., "e2e4")

Constants

files → const List<String>
ranks → const List<String>