MuZeroTrainer class

Constructors

MuZeroTrainer(MuZeroModel model, Adam optimizer)

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBufferSize int
final
model MuZeroModel
final
optimizer Adam
final
replayBuffer List<GameStep>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeMove(Move m, Game game) int
Maps a Bishop Move to our model's 0-4097 action space. Bishop moves contain 'from' and 'to' integer indices (0-63 for standard chess).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runSelfPlaySession(int numGames) Future<void>
toString() String
A string representation of this object.
inherited
trainStep({int batchSize = 32}) double
The optimization step (identical logic to previous version)

Operators

operator ==(Object other) bool
The equality operator.
inherited