UCIHandler class

Constructors

UCIHandler(MuZeroModel model)

Properties

game ↔ Game
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDebug bool
getter/setter pair
model MuZeroModel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
The main loop that reads from stdin
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited