Adam class

Constructors

Adam(List<Tensor> parameters, {double lr = 0.001, double beta1 = 0.9, double beta2 = 0.999, double epsilon = 1e-8})

Properties

beta1 double
final
beta2 double
final
epsilon double
final
hashCode int
The hash code for this object.
no setterinherited
lr double
final
m List<List<double>>
final
parameters List<Tensor>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
t int
getter/setter pair
v List<List<double>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step() → void
toString() String
A string representation of this object.
inherited
zeroGrad() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited