MCTSNode class

Constructors

MCTSNode(Tensor state)

Properties

children Map<int, MCTSNode>
final
hashCode int
The hash code for this object.
no setterinherited
priors Map<int, double>
getter/setter pair
rewards Map<int, double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Tensor
final
valueSums Map<int, double>
final
visitCounts Map<int, int>
final

Methods

getQ(int action) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited