MuZeroSearch class
Constructors
- MuZeroSearch(MuZeroModel model)
Properties
Methods
-
filterPriors(
List< double> logits, List<int> legalActions) → Map<int, double> - Public version of prior filtering used by the Trainer
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runSimulation(
MCTSNode root) → void - Performs a single MCTS simulation (Select -> Expand -> Evaluate -> Backup)
-
search(
Tensor rootState, List< int> legalActions, {int numSimulations = 50}) → int - Main entry point for playing: Runs simulations and returns the best move.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited